@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2021,2023,2025 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -44,7 +44,7 @@
 /**                # Version 6.1  : from : 28 feb 2021     **/
 /**                                 to   : 28 feb 2021     **/
 /**                # Version 7.0  : from : 21 jan 2023     **/
-/**                                 to   : 21 jan 2023     **/
+/**                                 to   : 28 jul 2025     **/
 /**                                                        **/
 /************************************************************/
 
@@ -83,7 +83,7 @@ SCOTCH_Graph * restrict const       grafptr)
 /*+ This routine builds an opaque dual graph structure
 *** from an opaque mesh structure. The dual graph adjacency
 *** is defined such that two elements are adjacent, if
-*** both shared at least ncommon points
+*** both shared at least noconbr points.
 *** - 0   : if building has succeeded.
 *** - !0  : on error.
 +*/
@@ -92,7 +92,7 @@ int
 SCOTCH_meshGraphDual (
 const SCOTCH_Mesh * restrict const  meshptr,
 SCOTCH_Graph * restrict const       grafptr,
-const SCOTCH_Num                    ncommon)
+const SCOTCH_Num                    noconbr)
 {
-  return (meshGraphDual ((Mesh *) meshptr, (Graph *) grafptr, ncommon));
+  return (meshGraphDual ((Mesh *) meshptr, (Graph *) grafptr, noconbr));
 }
