@@ -55,7 +55,7 @@
 /**                # Version 6.1  : from : 24 aug 2020     **/
 /**                                 to   : 30 dec 2021     **/
 /**                # Version 7.0  : from : 19 feb 2018     **/
-/**                                 to   : 31 jan 2025     **/
+/**                                 to   : 29 aug 2025     **/
 /**                                                        **/
 /************************************************************/
 
@@ -158,6 +158,7 @@
 #define SCOTCH_DEBUG_BGRAPH2
 #define SCOTCH_DEBUG_DGRAPH2
 #define SCOTCH_DEBUG_DMAP2
+#define SCOTCH_DEBUG_DMESH2
 #define SCOTCH_DEBUG_DORDER2
 #define SCOTCH_DEBUG_GEOM2
 #define SCOTCH_DEBUG_GRAPH2
@@ -188,6 +189,7 @@
 #define SCOTCH_DEBUG_BGRAPH1
 #define SCOTCH_DEBUG_DGRAPH1
 #define SCOTCH_DEBUG_DMAP1
+#define SCOTCH_DEBUG_DMESH1
 #define SCOTCH_DEBUG_DORDER1
 #define SCOTCH_DEBUG_GEOM1
 #define SCOTCH_DEBUG_GRAPH1
@@ -263,6 +265,8 @@
 #define SCOTCH_COARSENFOLD          SCOTCH_NAME_PUBLIC (SCOTCH_COARSENFOLD)
 #define SCOTCH_COARSENFOLDDUP       SCOTCH_NAME_PUBLIC (SCOTCH_COARSENFOLDDUP)
 #define SCOTCH_COARSENNOMERGE       SCOTCH_NAME_PUBLIC (SCOTCH_COARSENNOMERGE)
+#define SCOTCH_NUMMAX               SCOTCH_NAME_PUBLIC (SCOTCH_NUMMAX)
+#define SCOTCH_NUMSTRING            SCOTCH_NAME_PUBLIC (SCOTCH_NUMSTRING)
 #define SCOTCH_STRATDEFAULT         SCOTCH_NAME_PUBLIC (SCOTCH_STRATDEFAULT)
 #define SCOTCH_STRATQUALITY         SCOTCH_NAME_PUBLIC (SCOTCH_STRATQUALITY)
 #define SCOTCH_STRATSPEED           SCOTCH_NAME_PUBLIC (SCOTCH_STRATSPEED)
@@ -275,26 +279,30 @@
 #define SCOTCH_STRATLEVELMIN        SCOTCH_NAME_PUBLIC (SCOTCH_STRATLEVELMIN)
 #define SCOTCH_STRATLEAFSIMPLE      SCOTCH_NAME_PUBLIC (SCOTCH_STRATLEAFSIMPLE)
 #define SCOTCH_STRATSEPASIMPLE      SCOTCH_NAME_PUBLIC (SCOTCH_STRATSEPASIMPLE)
-#endif /* SCOTCH_RENAME_ALL */
+#define SCOTCH_STRATDISCONNECTED    SCOTCH_NAME_PUBLIC (SCOTCH_STRATDISCONNECTED)
 
-#ifdef SCOTCH_RENAME
 #define SCOTCH_Arch                 SCOTCH_NAME_PUBLIC (SCOTCH_Arch)
+#define SCOTCH_ArchDom              SCOTCH_NAME_PUBLIC (SCOTCH_ArchDom)
+#define SCOTCH_Context              SCOTCH_NAME_PUBLIC (SCOTCH_Context)
+#define SCOTCH_Dgraph               SCOTCH_NAME_PUBLIC (SCOTCH_Dgraph)
+#define SCOTCH_DgraphHaloReq        SCOTCH_NAME_PUBLIC (SCOTCH_DgraphHaloReq)
+#define SCOTCH_Dmapping             SCOTCH_NAME_PUBLIC (SCOTCH_Dmapping)
+#define SCOTCH_Dordering            SCOTCH_NAME_PUBLIC (SCOTCH_Dordering)
 #define SCOTCH_Geom                 SCOTCH_NAME_PUBLIC (SCOTCH_Geom)
 #define SCOTCH_Graph                SCOTCH_NAME_PUBLIC (SCOTCH_Graph)
+#define SCOTCH_GraphPart2           SCOTCH_NAME_PUBLIC (SCOTCH_GraphPart2)
 #define SCOTCH_Idx                  SCOTCH_NAME_PUBLIC (SCOTCH_Idx)
 #define SCOTCH_Mesh                 SCOTCH_NAME_PUBLIC (SCOTCH_Mesh)
 #define SCOTCH_Mapping              SCOTCH_NAME_PUBLIC (SCOTCH_Mapping)
 #define SCOTCH_Num                  SCOTCH_NAME_PUBLIC (SCOTCH_Num)
 #define SCOTCH_Ordering             SCOTCH_NAME_PUBLIC (SCOTCH_Ordering)
 #define SCOTCH_Strat                SCOTCH_NAME_PUBLIC (SCOTCH_Strat)
-#endif /* SCOTCH_RENAME */
+#endif /* SCOTCH_RENAME_ALL */
 
-#ifdef SCOTCH_COMMON_RENAME
-#define SCOTCH_NAME_GLOBAL(n)       SCOTCH_NAME_MACRO2 (SCOTCH_, n) /* Same name whatever the suffix is, since external library */
+#define SCOTCH_NAME_GLOBAL(n)       SCOTCH_NAME_MACRO2 (SCOTCH_, n) /* Always renamed, since exposed in Scotch user's manual */
 #define errorPrint                  SCOTCH_NAME_GLOBAL (errorPrint)
 #define errorPrintW                 SCOTCH_NAME_GLOBAL (errorPrintW)
 #define errorProg                   SCOTCH_NAME_GLOBAL (errorProg)
-#endif /* SCOTCH_COMMON_RENAME */
 
 #if ((defined SCOTCH_COMMON_RENAME) && ! (defined SCOTCH_COMMON_INTERNAL))
 #define clockGet                    SCOTCH_NAME_INTERN (clockGet)
@@ -790,6 +798,13 @@
 #define dmapTerm                    SCOTCH_NAME_INTERN (dmapTerm)
 #define dmapSave                    SCOTCH_NAME_INTERN (dmapSave)
 
+#define dmeshBuildAdm               SCOTCH_NAME_INTERN (dmeshBuildAdm)
+#define dmeshDgraphDual             SCOTCH_NAME_INTERN (dmeshDgraphDual)
+#define dmeshExit                   SCOTCH_NAME_INTERN (dmeshExit)
+#define dmeshFree                   SCOTCH_NAME_INTERN (dmeshFree)
+#define dmeshInit                   SCOTCH_NAME_INTERN (dmeshInit)
+#define dmeshLoad                   SCOTCH_NAME_INTERN (dmeshLoad)
+
 #define dorderDispose               SCOTCH_NAME_INTERN (dorderDispose)
 #define dorderExit                  SCOTCH_NAME_INTERN (dorderExit)
 #define dorderFree                  SCOTCH_NAME_INTERN (dorderFree)
@@ -1030,10 +1045,16 @@
 #define stratCondEval               SCOTCH_NAME_INTERN (stratCondEval)
 #define stratCondExit               SCOTCH_NAME_INTERN (stratCondExit)
 #define stratCondSave               SCOTCH_NAME_INTERN (stratCondSave)
-#define stratParserBegin            SCOTCH_NAME_INTERN (stratParserBegin)
 #define stratParserInit             SCOTCH_NAME_INTERN (stratParserInit)
 #define stratParserInput            SCOTCH_NAME_INTERN (stratParserInput)
 #define stratParserLex              SCOTCH_NAME_INTERN (stratParserLex)
+#define stratParserLexBegin         SCOTCH_NAME_INTERN (stratParserLexBegin)
+#define stratParserLexBufDelete     SCOTCH_NAME_INTERN (stratParserLexBufDelete)
+#define stratParserLexBufDestroy    SCOTCH_NAME_INTERN (stratParserLexBufDestroy)
+#define stratParserLexBufSwitch     SCOTCH_NAME_INTERN (stratParserLexBufSwitch)
+#define stratParserLexDestroy       SCOTCH_NAME_INTERN (stratParserLexDestroy)
+#define stratParserLexInit          SCOTCH_NAME_INTERN (stratParserLexInit)
+#define stratParserLexScanString    SCOTCH_NAME_INTERN (stratParserLexScanString)
 #define stratParserRemain           SCOTCH_NAME_INTERN (stratParserRemain)
 #define stratParserSelect           SCOTCH_NAME_INTERN (stratParserSelect)
 #define stratParserParse            SCOTCH_NAME_INTERN (stratParserParse)
@@ -1156,11 +1177,13 @@
 #define SCOTCH_archVar              SCOTCH_NAME_PUBLIC (SCOTCH_archVar)
 #define SCOTCH_archVcmplt           SCOTCH_NAME_PUBLIC (SCOTCH_archVcmplt)
 #define SCOTCH_archVhcub            SCOTCH_NAME_PUBLIC (SCOTCH_archVhcub)
+#define SCOTCH_contextBindDgraph    SCOTCH_NAME_PUBLIC (SCOTCH_contextBindDgraph)
 #define SCOTCH_contextBindGraph     SCOTCH_NAME_PUBLIC (SCOTCH_contextBindGraph)
 #define SCOTCH_contextBindMesh      SCOTCH_NAME_PUBLIC (SCOTCH_contextBindMesh)
 #define SCOTCH_contextExit          SCOTCH_NAME_PUBLIC (SCOTCH_contextExit)
 #define SCOTCH_contextInit          SCOTCH_NAME_PUBLIC (SCOTCH_contextInit)
 #define SCOTCH_contextOptionGetNum  SCOTCH_NAME_PUBLIC (SCOTCH_contextOptionGetNum)
+#define SCOTCH_contextOptionParse   SCOTCH_NAME_PUBLIC (SCOTCH_contextOptionParse)
 #define SCOTCH_contextOptionSetNum  SCOTCH_NAME_PUBLIC (SCOTCH_contextOptionSetNum)
 #define SCOTCH_contextRandomClone   SCOTCH_NAME_PUBLIC (SCOTCH_contextRandomClone)
 #define SCOTCH_contextRandomReset   SCOTCH_NAME_PUBLIC (SCOTCH_contextRandomReset)
@@ -1175,6 +1198,7 @@
 #define SCOTCH_dgraphBuildGrid3D    SCOTCH_NAME_PUBLIC (SCOTCH_dgraphBuildGrid3D)
 #define SCOTCH_dgraphCheck          SCOTCH_NAME_PUBLIC (SCOTCH_dgraphCheck)
 #define SCOTCH_dgraphCoarsen        SCOTCH_NAME_PUBLIC (SCOTCH_dgraphCoarsen)
+#define SCOTCH_dgraphCoarsenVertLocMax SCOTCH_NAME_PUBLIC (SCOTCH_dgraphCoarsenVertLocMax)
 #define SCOTCH_dgraphCorderExit     SCOTCH_NAME_PUBLIC (SCOTCH_dgraphCorderExit)
 #define SCOTCH_dgraphCorderInit     SCOTCH_NAME_PUBLIC (SCOTCH_dgraphCorderInit)
 #define SCOTCH_dgraphData           SCOTCH_NAME_PUBLIC (SCOTCH_dgraphData)
@@ -1185,6 +1209,7 @@
 #define SCOTCH_dgraphGhstReplace    SCOTCH_NAME_PUBLIC (SCOTCH_dgraphGhstReplace)
 #define SCOTCH_dgraphGrow           SCOTCH_NAME_PUBLIC (SCOTCH_dgraphGrow)
 #define SCOTCH_dgraphHalo           SCOTCH_NAME_PUBLIC (SCOTCH_dgraphHalo)
+#define SCOTCH_dgraphHaloReqSizeof  SCOTCH_NAME_PUBLIC (SCOTCH_dgraphHaloReqSizeof)
 #define SCOTCH_dgraphHaloAsync      SCOTCH_NAME_PUBLIC (SCOTCH_dgraphHaloAsync)
 #define SCOTCH_dgraphHaloReqAlloc   SCOTCH_NAME_PUBLIC (SCOTCH_dgraphHaloReqAlloc)
 #define SCOTCH_dgraphHaloWait       SCOTCH_NAME_PUBLIC (SCOTCH_dgraphHaloWait)
@@ -1236,6 +1261,7 @@
 #define SCOTCH_graphColor           SCOTCH_NAME_PUBLIC (SCOTCH_graphColor)
 #define SCOTCH_graphData            SCOTCH_NAME_PUBLIC (SCOTCH_graphData)
 #define SCOTCH_graphDiamPV          SCOTCH_NAME_PUBLIC (SCOTCH_graphDiamPV)
+#define SCOTCH_graphDump            SCOTCH_NAME_PUBLIC (SCOTCH_graphDump)
 #define SCOTCH_graphExit            SCOTCH_NAME_PUBLIC (SCOTCH_graphExit)
 #define SCOTCH_graphFree            SCOTCH_NAME_PUBLIC (SCOTCH_graphFree)
 #define SCOTCH_graphGeomLoadChac    SCOTCH_NAME_PUBLIC (SCOTCH_graphGeomLoadChac)
@@ -1273,6 +1299,7 @@
 #define SCOTCH_graphPart            SCOTCH_NAME_PUBLIC (SCOTCH_graphPart)
 #define SCOTCH_graphPartFixed       SCOTCH_NAME_PUBLIC (SCOTCH_graphPartFixed)
 #define SCOTCH_graphPartOvl         SCOTCH_NAME_PUBLIC (SCOTCH_graphPartOvl)
+#define SCOTCH_graphPartOvlView     SCOTCH_NAME_PUBLIC (SCOTCH_graphPartOvlView)
 #define SCOTCH_graphRemap           SCOTCH_NAME_PUBLIC (SCOTCH_graphRemap)
 #define SCOTCH_graphRemapCompute    SCOTCH_NAME_PUBLIC (SCOTCH_graphRemapCompute)
 #define SCOTCH_graphRemapFixed      SCOTCH_NAME_PUBLIC (SCOTCH_graphRemapFixed)
